@@ -2,7 +2,6 @@ var searchData=
 [
   ['saxdocumentbuilder',['SAXDocumentBuilder',['../servicecom_1_1sun_1_1star_1_1xml_1_1dom_1_1SAXDocumentBuilder.html',1,'com::sun::star::xml::dom']]],
   ['saxdocumenthandler',['SaxDocumentHandler',['../servicecom_1_1sun_1_1star_1_1xml_1_1input_1_1SaxDocumentHandler.html',1,'com::sun::star::xml::input']]],
-  ['saxeventkeeper',['SAXEventKeeper',['../servicecom_1_1sun_1_1star_1_1xml_1_1crypto_1_1sax_1_1SAXEventKeeper.html',1,'com::sun::star::xml::crypto::sax']]],
   ['saxexception',['SAXException',['../exceptioncom_1_1sun_1_1star_1_1xml_1_1sax_1_1SAXException.html',1,'com::sun::star::xml::sax']]],
   ['saxinvalidcharacterexception',['SAXInvalidCharacterException',['../exceptioncom_1_1sun_1_1star_1_1xml_1_1sax_1_1SAXInvalidCharacterException.html',1,'com::sun::star::xml::sax']]],
   ['saxparseexception',['SAXParseException',['../exceptioncom_1_1sun_1_1star_1_1xml_1_1sax_1_1SAXParseException.html',1,'com::sun::star::xml::sax']]],
@@ -59,19 +58,13 @@ var searchData=
   ['sessionmanager',['SessionManager',['../servicecom_1_1sun_1_1star_1_1frame_1_1SessionManager.html',1,'com::sun::star::frame']]],
   ['setaccess',['SetAccess',['../servicecom_1_1sun_1_1star_1_1configuration_1_1SetAccess.html',1,'com::sun::star::configuration']]],
   ['setelement',['SetElement',['../servicecom_1_1sun_1_1star_1_1configuration_1_1SetElement.html',1,'com::sun::star::configuration']]],
-  ['setexpression',['SetExpression',['../servicecom_1_1sun_1_1star_1_1text_1_1fieldmaster_1_1SetExpression.html',1,'com::sun::star::text::fieldmaster']]],
-  ['setexpression',['SetExpression',['../servicecom_1_1sun_1_1star_1_1text_1_1textfield_1_1SetExpression.html',1,'com::sun::star::text::textfield']]],
+  ['setexpression',['SetExpression',['../servicecom_1_1sun_1_1star_1_1text_1_1fieldmaster_1_1SetExpression.html',1,'SetExpression'],['../servicecom_1_1sun_1_1star_1_1text_1_1textfield_1_1SetExpression.html',1,'SetExpression']]],
   ['setpropertytolerantfailed',['SetPropertyTolerantFailed',['../structcom_1_1sun_1_1star_1_1beans_1_1SetPropertyTolerantFailed.html',1,'com::sun::star::beans']]],
-  ['settings',['Settings',['../servicecom_1_1sun_1_1star_1_1frame_1_1Settings.html',1,'com::sun::star::frame']]],
-  ['settings',['Settings',['../servicecom_1_1sun_1_1star_1_1document_1_1Settings.html',1,'com::sun::star::document']]],
+  ['settings',['Settings',['../servicecom_1_1sun_1_1star_1_1document_1_1Settings.html',1,'Settings'],['../servicecom_1_1sun_1_1star_1_1frame_1_1Settings.html',1,'Settings']]],
   ['setupdate',['SetUpdate',['../servicecom_1_1sun_1_1star_1_1configuration_1_1SetUpdate.html',1,'com::sun::star::configuration']]],
   ['shadowformat',['ShadowFormat',['../structcom_1_1sun_1_1star_1_1table_1_1ShadowFormat.html',1,'com::sun::star::table']]],
   ['shadowproperties',['ShadowProperties',['../servicecom_1_1sun_1_1star_1_1drawing_1_1ShadowProperties.html',1,'com::sun::star::drawing']]],
-  ['shape',['Shape',['../servicecom_1_1sun_1_1star_1_1report_1_1Shape.html',1,'com::sun::star::report']]],
-  ['shape',['Shape',['../servicecom_1_1sun_1_1star_1_1sheet_1_1Shape.html',1,'com::sun::star::sheet']]],
-  ['shape',['Shape',['../servicecom_1_1sun_1_1star_1_1drawing_1_1Shape.html',1,'com::sun::star::drawing']]],
-  ['shape',['Shape',['../servicecom_1_1sun_1_1star_1_1text_1_1Shape.html',1,'com::sun::star::text']]],
-  ['shape',['Shape',['../servicecom_1_1sun_1_1star_1_1presentation_1_1Shape.html',1,'com::sun::star::presentation']]],
+  ['shape',['Shape',['../servicecom_1_1sun_1_1star_1_1report_1_1Shape.html',1,'Shape'],['../servicecom_1_1sun_1_1star_1_1sheet_1_1Shape.html',1,'Shape'],['../servicecom_1_1sun_1_1star_1_1drawing_1_1Shape.html',1,'Shape'],['../servicecom_1_1sun_1_1star_1_1text_1_1Shape.html',1,'Shape'],['../servicecom_1_1sun_1_1star_1_1presentation_1_1Shape.html',1,'Shape']]],
   ['shapecollection',['ShapeCollection',['../servicecom_1_1sun_1_1star_1_1drawing_1_1ShapeCollection.html',1,'com::sun::star::drawing']]],
   ['shapes',['Shapes',['../servicecom_1_1sun_1_1star_1_1drawing_1_1Shapes.html',1,'com::sun::star::drawing']]],
   ['sharedlibrary',['SharedLibrary',['../servicecom_1_1sun_1_1star_1_1loader_1_1SharedLibrary.html',1,'com::sun::star::loader']]],
@@ -87,13 +80,10 @@ var searchData=
   ['sheetrangesquery',['SheetRangesQuery',['../servicecom_1_1sun_1_1star_1_1sheet_1_1SheetRangesQuery.html',1,'com::sun::star::sheet']]],
   ['sheetsortdescriptor',['SheetSortDescriptor',['../servicecom_1_1sun_1_1star_1_1sheet_1_1SheetSortDescriptor.html',1,'com::sun::star::sheet']]],
   ['sheetsortdescriptor2',['SheetSortDescriptor2',['../servicecom_1_1sun_1_1star_1_1sheet_1_1SheetSortDescriptor2.html',1,'com::sun::star::sheet']]],
-  ['signaturecreator',['SignatureCreator',['../servicecom_1_1sun_1_1star_1_1xml_1_1crypto_1_1sax_1_1SignatureCreator.html',1,'com::sun::star::xml::crypto::sax']]],
   ['signatureexception',['SignatureException',['../exceptioncom_1_1sun_1_1star_1_1security_1_1SignatureException.html',1,'com::sun::star::security']]],
-  ['signatureverifier',['SignatureVerifier',['../servicecom_1_1sun_1_1star_1_1xml_1_1crypto_1_1sax_1_1SignatureVerifier.html',1,'com::sun::star::xml::crypto::sax']]],
   ['simplecommandmail',['SimpleCommandMail',['../servicecom_1_1sun_1_1star_1_1system_1_1SimpleCommandMail.html',1,'com::sun::star::system']]],
   ['simplefileaccess',['SimpleFileAccess',['../servicecom_1_1sun_1_1star_1_1ucb_1_1SimpleFileAccess.html',1,'com::sun::star::ucb']]],
   ['simplefontmetric',['SimpleFontMetric',['../structcom_1_1sun_1_1star_1_1awt_1_1SimpleFontMetric.html',1,'com::sun::star::awt']]],
-  ['simplelogring',['SimpleLogRing',['../servicecom_1_1sun_1_1star_1_1logging_1_1SimpleLogRing.html',1,'com::sun::star::logging']]],
   ['simpleregistry',['SimpleRegistry',['../servicecom_1_1sun_1_1star_1_1registry_1_1SimpleRegistry.html',1,'com::sun::star::registry']]],
   ['simplesetaccess',['SimpleSetAccess',['../servicecom_1_1sun_1_1star_1_1configuration_1_1SimpleSetAccess.html',1,'com::sun::star::configuration']]],
   ['simplesetupdate',['SimpleSetUpdate',['../servicecom_1_1sun_1_1star_1_1configuration_1_1SimpleSetUpdate.html',1,'com::sun::star::configuration']]],
@@ -150,9 +140,7 @@ var searchData=
   ['standarddiagramcreationparameters',['StandardDiagramCreationParameters',['../servicecom_1_1sun_1_1star_1_1chart2_1_1StandardDiagramCreationParameters.html',1,'com::sun::star::chart2']]],
   ['startmodule',['StartModule',['../servicecom_1_1sun_1_1star_1_1frame_1_1StartModule.html',1,'com::sun::star::frame']]],
   ['statechangeinprogressexception',['StateChangeInProgressException',['../exceptioncom_1_1sun_1_1star_1_1embed_1_1StateChangeInProgressException.html',1,'com::sun::star::embed']]],
-  ['statement',['Statement',['../servicecom_1_1sun_1_1star_1_1sdbcx_1_1Statement.html',1,'com::sun::star::sdbcx']]],
-  ['statement',['Statement',['../servicecom_1_1sun_1_1star_1_1sdbc_1_1Statement.html',1,'com::sun::star::sdbc']]],
-  ['statement',['Statement',['../structcom_1_1sun_1_1star_1_1rdf_1_1Statement.html',1,'com::sun::star::rdf']]],
+  ['statement',['Statement',['../structcom_1_1sun_1_1star_1_1rdf_1_1Statement.html',1,'Statement'],['../servicecom_1_1sun_1_1star_1_1sdbc_1_1Statement.html',1,'Statement'],['../servicecom_1_1sun_1_1star_1_1sdbcx_1_1Statement.html',1,'Statement']]],
   ['statusbarcontroller',['StatusbarController',['../servicecom_1_1sun_1_1star_1_1frame_1_1StatusbarController.html',1,'com::sun::star::frame']]],
   ['statusbarcontrollerfactory',['StatusbarControllerFactory',['../servicecom_1_1sun_1_1star_1_1frame_1_1StatusbarControllerFactory.html',1,'com::sun::star::frame']]],
   ['statusindicatorfactory',['StatusIndicatorFactory',['../servicecom_1_1sun_1_1star_1_1task_1_1StatusIndicatorFactory.html',1,'com::sun::star::task']]],
@@ -177,8 +165,7 @@ var searchData=
   ['subincrement',['SubIncrement',['../structcom_1_1sun_1_1star_1_1chart2_1_1SubIncrement.html',1,'com::sun::star::chart2']]],
   ['subject',['Subject',['../servicecom_1_1sun_1_1star_1_1text_1_1textfield_1_1docinfo_1_1Subject.html',1,'com::sun::star::text::textfield::docinfo']]],
   ['submissionpropertyhandler',['SubmissionPropertyHandler',['../servicecom_1_1sun_1_1star_1_1form_1_1inspection_1_1SubmissionPropertyHandler.html',1,'com::sun::star::form::inspection']]],
-  ['submitbutton',['SubmitButton',['../servicecom_1_1sun_1_1star_1_1form_1_1component_1_1SubmitButton.html',1,'com::sun::star::form::component']]],
-  ['submitbutton',['SubmitButton',['../servicecom_1_1sun_1_1star_1_1form_1_1control_1_1SubmitButton.html',1,'com::sun::star::form::control']]],
+  ['submitbutton',['SubmitButton',['../servicecom_1_1sun_1_1star_1_1form_1_1component_1_1SubmitButton.html',1,'SubmitButton'],['../servicecom_1_1sun_1_1star_1_1form_1_1control_1_1SubmitButton.html',1,'SubmitButton']]],
   ['subtitleshape',['SubtitleShape',['../servicecom_1_1sun_1_1star_1_1presentation_1_1SubtitleShape.html',1,'com::sun::star::presentation']]],
   ['subtotalcolumn',['SubTotalColumn',['../structcom_1_1sun_1_1star_1_1sheet_1_1SubTotalColumn.html',1,'com::sun::star::sheet']]],
   ['subtotaldescriptor',['SubTotalDescriptor',['../servicecom_1_1sun_1_1star_1_1sheet_1_1SubTotalDescriptor.html',1,'com::sun::star::sheet']]],
